from gettext import gettext as _

from checkbox.plugin import Plugin
from checkbox.user_interface import PREV


class IntroPrompt(Plugin):

    def register(self, manager):
        super(IntroPrompt, self).register(manager)
        self._welcome_text = _("""\
Welcome to Unity Testing!

Thanks for helping us testing this version of Unity. This application will \
gather information from your system. You will then be asked to perform manual \
tests to confirm Unity is working nicely.

Please note the tests assume that you are using the default Unity settings.

Some tests require specific applications to be installed. It is safe to skip \
a test if you do not have a required application installed.

If a test doesn't pass, please add a comment to explain which steps failed.

You can safely quit Checkbox while testing: it will prompt you to resume your \
test session next time it is started.
""")

        self._recover = False

        self._manager.reactor.call_on("begin-recover", self.begin_recover)

        # Introduction should be prompted last
        self._manager.reactor.call_on("prompt-begin", self.prompt_begin, 100)

    def begin_recover(self, recover):
        self._recover = recover

    def prompt_begin(self, interface):
        if interface.direction == PREV or not self._recover:
            self._recover = False
            interface.show_text(self._welcome_text, previous="")


factory = IntroPrompt
